<?php
/*
 * --------------------------------------------------------------------------------
   iDEAL Checkout - Mastercard for K2 Store
 * --------------------------------------------------------------------------------
 * @package		Joomla! 1.5x
 * @subpackage	K2 Store
 * @author    	iDEAL Checkout www.ideal-checkout.nl
 * @copyright	Copyright (c) 2009 - 2013 iDEAL Checkout All rights reserved.
 * --------------------------------------------------------------------------------
*/

/** ensure this file is being included by a parent file */
defined('_JEXEC') or die('Restricted access');

require_once(JPATH_ADMINISTRATOR . '/components/com_k2store/library/plugins/payment.php');
require_once(JPATH_SITE . '/components/com_k2store/helpers/utilities.php');
require_once(JPATH_SITE . '/idealcheckout/includes/library.php');


class plgK2StorePayment_idealcheckoutmastercard extends K2StorePaymentPlugin
{
	/**
	 * @var $_element  string  Should always correspond with the plugin's filename, 
	 *                         forcing it to be unique 
	 */
    public $_element = 'payment_idealcheckoutmastercard';
    
	/**
	 * Constructor
	 *
	 * For php4 compatability we must not use the __constructor as a constructor for plugins
	 * because func_get_args ( void ) returns a copy of all passed arguments NOT references.
	 * This causes problems with cross-referencing necessary for the observer design pattern.
	 *
	 * @param object $subject The object to observe
	 * @param 	array  $config  An array that holds the plugin configuration
	 * @since 1.5
	 */
	function plgK2StorePayment_idealcheckoutmastercard(&$subject, $config) 
	{
		parent::__construct($subject, $config);
		$this->loadLanguage( '', JPATH_ADMINISTRATOR );
	}

   
    /**
     * @param $data     array       form post data
     * @return string   HTML to display
     */
    function _prePayment($data)
    {
		// get component params
		$params = &JComponentHelper::getParams('com_k2store');
        
        // prepare the payment form
        
        $vars = new JObject();

		$vars->order_id = $data['order_id'];
        $vars->orderpayment_id = $data['orderpayment_id'];
        $vars->orderpayment_amount = K2StoreUtilities::number( $data['orderpayment_amount'], array( 'thousands'=>'', 'num_decimals'=>'2', 'decimal'=>'.') );
		$vars->orderpayment_type = $this->_element;

        // set payment plugin variables
		$vars->root_url = JURI::root();
        $vars->success_url = JURI::root() . 'index.php?option=com_k2store&view=checkout&task=confirmPayment&orderpayment_type=' . $this->_element . '&paction=success&order_id=' . $vars->order_id . '&orderpayment_id=' . $vars->orderpayment_id;
        $vars->cancelled_url = JURI::root() . 'index.php?option=com_k2store&view=checkout&task=confirmPayment&orderpayment_type=' . $this->_element . '&paction=cancelled&order_id=' . $vars->order_id . '&orderpayment_id=' . $vars->orderpayment_id;
        $vars->pending_url = JURI::root() . 'index.php?option=com_k2store&view=checkout&task=confirmPayment&orderpayment_type=' . $this->_element . '&paction=pending&order_id=' . $vars->order_id . '&orderpayment_id=' . $vars->orderpayment_id;
        $vars->currency_code = $params->get('currency_code');
		
        $html = $this->_getLayout('prepayment', $vars);
        return $html;
    }
    
    /**
     * Processes the payment form
     * and returns HTML to be displayed to the user
     * generally with a success/failed message
     *  
     * @param $data     array       form post data
     * @return string   HTML to display
     */
    function _postPayment($data)
    {
		// Process the payment
        $paction = JRequest::getVar('paction');        
        $vars = new JObject();
		$aLanguage = JFactory::getLanguage();
		$sLanguageCode = strtolower(substr($aLanguage->get('tag'), 0, 2));
		$iOrderId = JRequest::getVar('order_id'); 
		$iOrderpaymentId = JRequest::getVar('orderpayment_id'); 
		$aDatabaseSettings = idealcheckout_getDatabaseSettings();

		$sql = "SELECT * FROM `" . $aDatabaseSettings['prefix'] . "k2store_orders` WHERE (`id` = '" . $iOrderpaymentId . "') AND (`order_id` = '" . $iOrderId . "') LIMIT 1;";
		$rsOrder = idealcheckout_database_getRecord($sql);

         // let us inform the user that the order is successful
        require_once (JPATH_SITE . DS . 'components' . DS . 'com_k2store' . DS . 'helpers' . DS . 'orders.php');
        K2StoreOrdersHelper::sendUserEmail($rsOrder['user_id'], $rsOrder['order_id'], $rsOrder['transaction_status'], $rsOrder['order_state'], $rsOrder['order_state_id']);



		switch ($paction) 
		{
			case "success":
                $vars->message = idealcheckout_getTranslation($sLanguageCode, 'k2store', 'Your payment was recieved.');
                $html = $this->_getLayout('message', $vars);
                $html .= $this->_displayArticle();

				$this->resetCart();
              break;
            case "pending":
                $vars->message = idealcheckout_getTranslation($sLanguageCode, 'k2store', 'Your payment is pending.');
                $html = $this->_getLayout('message', $vars);
                // $html .= $this->_displayArticle();
              break;
            case "cancelled":
                $vars->message = idealcheckout_getTranslation($sLanguageCode, 'k2store', 'Your payment was cancelled.');
                $html = $this->_getLayout('message', $vars);
                // $html .= $this->_displayArticle();
              break;
            default:
                $vars->message = idealcheckout_getTranslation($sLanguageCode, 'k2store', 'Payment status unknown.');
                $html = $this->_getLayout('message', $vars);
              break;
        }
        
        return $html;
    }   
    
	public function resetCart()
	{
		if(isset($_SESSION['__default']['k2store_cart']))
		{
			unset($_SESSION['__default']['k2store_cart']);
		}
	}


    /**
     * Prepares variables for the payment form
     * 
     * @return unknown_type
     */
    function _renderForm( $data )
    {
        $user = JFactory::getUser();    
        $vars = new JObject();
        
        $html = $this->_getLayout('form', $vars);
        
        return $html;
    }

    /**
     * Formatts the payment data for storing
     * 
     * @param array $data
     * @return string
     */
    function _getFormattedTransactionDetails( $data )
    {
        $separator = "\n";
        $formatted = array();

        foreach ($data as $key => $value) 
        {
            if ($key != 'view' && $key != 'layout') 
            {
                $formatted[] = $key . ' = ' . $value;
            }
        }
        
        return count($formatted) ? implode("\n", $formatted) : '';  
    }

 
    
    
    
}

    